unit setType;

interface

uses
    Windows, SysUtils, Registry;

type
   TRegistration = class(TRegistry)
   public
     constructor Create;
     procedure   SetKey(Root : HKEY;Key : String);
     function    GetStrValue(AKey : String;Ident : String) : String;
     procedure   SetStrValue(AKey : String;Ident : String;Value : String);
     function    GetIntValue(AKey : String;Ident : String) : Longint;
     procedure   SetIntValue(AKey : String;Ident : String;Value : Longint);
     function    GetFloatValue(AKey : String;Ident : String) : Extended;
     procedure   SetFloatValue(AKey : String;Ident : String;Value : Extended);
   end;

implementation

const
     REGCDK_STRING = 'Software\BOBOSOFT\open CDK\1.10';

constructor TRegistration.Create;
begin
     inherited Create;
end;

procedure TRegistration.SetKey(Root : HKEY;Key : String);
begin
     RootKey := Root;
     OpenKey(Key, True);
end;

function TRegistration.GetStrValue(AKey : String;Ident : String) : String;
var
   Key, OldKey: HKEY;
begin
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      if ValueExists(Ident) then
        Result := inherited ReadString(Ident) else
        Result := '';
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end
  else Result := '';
end;

procedure TRegistration.SetStrValue(AKey : String;Ident : String;Value : String);
var
   Key, OldKey: HKEY;
begin
  CreateKey(AKey);
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      inherited WriteString(Ident, Value);
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end;
end;

function TRegistration.GetIntValue(AKey : String;Ident : String) : Longint;
var
   Key, OldKey: HKEY;
begin
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      if ValueExists(Ident) then
        Result := inherited ReadInteger(Ident) else
        Result := -1;
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end
  else Result := -1;
end;

procedure TRegistration.SetIntValue(AKey : String;Ident : String;Value : Longint);
var
   Key, OldKey: HKEY;
begin
  CreateKey(AKey);
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      inherited WriteInteger(Ident, Value);
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end;
end;

function TRegistration.GetFloatValue(AKey : String;Ident : String) : Extended;
var
   Key, OldKey: HKEY;
begin
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      if ValueExists(Ident) then
        Result := inherited ReadFloat(Ident) else
        Result := 0;
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end
  else Result := 0;
end;

procedure TRegistration.SetFloatValue(AKey : String;Ident : String;Value : Extended);
var
   Key, OldKey: HKEY;
begin
  CreateKey(AKey);
  Key := GetKey(AKey);
  if Key <> 0 then
  try
    OldKey := CurrentKey;
    SetCurrentKey(Key);
    try
      inherited WriteFloat(Ident, Value);
    finally
      SetCurrentKey(OldKey);
    end;
  finally
    RegCloseKey(Key);
  end;
end;

end.
